@@ -98,10 +98,11 @@ class Renderer(JsRenderer, JsCacheRenderer):
             # actors={a.actor_id: a for a in self.actors_list},
             menu=settings.SITE.get_site_menu(get_user_profile()),
             suggestors=list(plugins.memo.parser.suggesters.keys()),  # [#,@] keytriggers
+            use_dashboard_layouts=plugins.system.use_dashboard_layouts,
             )
 
         if settings.SITE.is_installed('notify'):
-            data.update(vapid_public_key=plugins.notify.vapid_public_key)
+            data.update(use_push_api=plugins.notify.use_push_api)
 
         # data.update(actors={str(a): a for a in self.actors_list})
         # data.update(action_param_panels={
@@ -355,9 +356,9 @@ class Renderer(JsRenderer, JsCacheRenderer):
                           http_method=v.http_method,
                           )
 
-            href_target = v.get_a_href_target()
-            if href_target:
-                result.update(href=href_target)
+            # href_target = v.get_a_href_target()
+            # if href_target:
+            #     result.update(href=href_target)
 
             if isinstance(v, QuickLinkAction):
                 result['an'] = v.bound_action.action.action_name
@@ -553,7 +554,7 @@ class Renderer(JsRenderer, JsCacheRenderer):
                                   "max_render_depth "
                                   "simple_slavegrid_header "
                                   "paginator_template "
-                                  "hide_top_toolbar "
+                                  # "hide_top_toolbar "
                                   "hide_if_empty "
                                   "borderless_list_mode "
                                ))
