@@ -456,12 +456,12 @@ class MainHtml(View):
         # ~ logger.info("20130719 MainHtml")
         settings.SITE.startup()
         # ~ raise Exception("20131023")
-        ar = BaseRequest(request)
+        rnd = settings.SITE.plugins.react.renderer
+        ar = BaseRequest(request, renderer=rnd)
         # Add to reqeust not ar, as there's error if passing ar to get_main_html
         request.requesting_panel = "dashboard-main"
-        html = settings.SITE.get_main_html(
-            request, front_end=settings.SITE.plugins.react)
-        html = settings.SITE.plugins.react.renderer.html_text(html)
+        html = settings.SITE.get_main_html(ar)
+        html = rnd.html_text(html)
         ar.success(html=html)
         return json_response(ar.response, ar.content_type)
 
